# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waBotMetadata/WABotMetadata.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'waBotMetadata/WABotMetadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!waBotMetadata/WABotMetadata.proto\x12\rWABotMetadata\x1a\x17waCommon/WACommon.proto\"\x85\x05\n\x11\x42otPluginMetadata\x12\x41\n\x08provider\x18\x01 \x01(\x0e\x32/.WABotMetadata.BotPluginMetadata.SearchProvider\x12?\n\npluginType\x18\x02 \x01(\x0e\x32+.WABotMetadata.BotPluginMetadata.PluginType\x12\x17\n\x0fthumbnailCDNURL\x18\x03 \x01(\t\x12\x1a\n\x12profilePhotoCDNURL\x18\x04 \x01(\t\x12\x19\n\x11searchProviderURL\x18\x05 \x01(\t\x12\x16\n\x0ereferenceIndex\x18\x06 \x01(\r\x12\x1a\n\x12\x65xpectedLinksCount\x18\x07 \x01(\r\x12\x13\n\x0bsearchQuery\x18\t \x01(\t\x12\x34\n\x16parentPluginMessageKey\x18\n \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x44\n\x0f\x64\x65precatedField\x18\x0b \x01(\x0e\x32+.WABotMetadata.BotPluginMetadata.PluginType\x12\x45\n\x10parentPluginType\x18\x0c \x01(\x0e\x32+.WABotMetadata.BotPluginMetadata.PluginType\x12\x15\n\rfaviconCDNURL\x18\r \x01(\t\"7\n\nPluginType\x12\x12\n\x0eUNKNOWN_PLUGIN\x10\x00\x12\t\n\x05REELS\x10\x01\x12\n\n\x06SEARCH\x10\x02\"@\n\x0eSearchProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x42ING\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x0b\n\x07SUPPORT\x10\x03\"\x8e\x01\n\x10\x42otLinkedAccount\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32\x34.WABotMetadata.BotLinkedAccount.BotLinkedAccountType\"6\n\x14\x42otLinkedAccountType\x12\x1e\n\x1a\x42OT_LINKED_ACCOUNT_TYPE_1P\x10\x00\"\xe5\x01\n$BotSignatureVerificationUseCaseProof\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12X\n\x07useCase\x18\x02 \x01(\x0e\x32G.WABotMetadata.BotSignatureVerificationUseCaseProof.BotSignatureUseCase\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12\x18\n\x10\x63\x65rtificateChain\x18\x04 \x01(\x0c\"%\n\x13\x42otSignatureUseCase\x12\x0e\n\nWA_BOT_MSG\x10\x00\"\xca\x01\n\x1b\x42otPromotionMessageMetadata\x12R\n\rpromotionType\x18\x01 \x01(\x0e\x32;.WABotMetadata.BotPromotionMessageMetadata.BotPromotionType\x12\x13\n\x0b\x62uttonTitle\x18\x02 \x01(\t\"B\n\x10\x42otPromotionType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x07\n\x03\x43\x35\x30\x10\x01\x12\x13\n\x0fSURVEY_PLATFORM\x10\x02\"\x8e\x02\n\x10\x42otMediaMetadata\x12\x12\n\nfileSHA256\x18\x01 \x01(\t\x12\x10\n\x08mediaKey\x18\x02 \x01(\t\x12\x15\n\rfileEncSHA256\x18\x03 \x01(\t\x12\x12\n\ndirectPath\x18\x04 \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\x12\x10\n\x08mimetype\x18\x06 \x01(\t\x12H\n\x0forientationType\x18\x07 \x01(\x0e\x32/.WABotMetadata.BotMediaMetadata.OrientationType\"2\n\x0fOrientationType\x12\n\n\x06\x43\x45NTER\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\t\n\x05RIGHT\x10\x03\"\x91\x03\n\x13\x42otReminderMetadata\x12/\n\x11requestMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x41\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x31.WABotMetadata.BotReminderMetadata.ReminderAction\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14nextTriggerTimestamp\x18\x04 \x01(\x04\x12G\n\tfrequency\x18\x05 \x01(\x0e\x32\x34.WABotMetadata.BotReminderMetadata.ReminderFrequency\"O\n\x11ReminderFrequency\x12\x08\n\x04ONCE\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\n\n\x06WEEKLY\x10\x03\x12\x0c\n\x08\x42IWEEKLY\x10\x04\x12\x0b\n\x07MONTHLY\x10\x05\"@\n\x0eReminderAction\x12\n\n\x06NOTIFY\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06UPDATE\x10\x04\"\xb8\x02\n\x10\x42otModelMetadata\x12<\n\tmodelType\x18\x01 \x01(\x0e\x32).WABotMetadata.BotModelMetadata.ModelType\x12N\n\x12premiumModelStatus\x18\x02 \x01(\x0e\x32\x32.WABotMetadata.BotModelMetadata.PremiumModelStatus\"O\n\x12PremiumModelStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\r\n\tAVAILABLE\x10\x01\x12\x16\n\x12QUOTA_EXCEED_LIMIT\x10\x02\"E\n\tModelType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0e\n\nLLAMA_PROD\x10\x01\x12\x16\n\x12LLAMA_PROD_PREMIUM\x10\x02\"\xd4\x0b\n\x1c\x42otProgressIndicatorMetadata\x12\x1b\n\x13progressDescription\x18\x01 \x01(\t\x12Z\n\rstepsMetadata\x18\x02 \x03(\x0b\x32\x43.WABotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata\x1a\xba\n\n\x17\x42otPlanningStepMetadata\x12\x13\n\x0bstatusTitle\x18\x01 \x01(\t\x12\x12\n\nstatusBody\x18\x02 \x01(\t\x12}\n\x0fsourcesMetadata\x18\x03 \x03(\x0b\x32\x64.WABotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourcesMetadata\x12\x66\n\x06status\x18\x04 \x01(\x0e\x32V.WABotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.PlanningStepStatus\x12\x13\n\x0bisReasoning\x18\x05 \x01(\x08\x12\x18\n\x10isEnhancedSearch\x18\x06 \x01(\x08\x12t\n\x08sections\x18\x07 \x03(\x0b\x32\x62.WABotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningStepSectionMetadata\x1a\xb5\x02\n BotPlanningSearchSourcesMetadata\x12\x13\n\x0bsourceTitle\x18\x01 \x01(\t\x12\x97\x01\n\x08provider\x18\x02 \x01(\x0e\x32\x84\x01.WABotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourcesMetadata.BotPlanningSearchSourceProvider\x12\x11\n\tsourceURL\x18\x03 \x01(\t\"O\n\x1f\x42otPlanningSearchSourceProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x08\n\x04\x42ING\x10\x03\x1a\xc9\x01\n\x1e\x42otPlanningStepSectionMetadata\x12\x14\n\x0csectionTitle\x18\x01 \x01(\t\x12\x13\n\x0bsectionBody\x18\x02 \x01(\t\x12|\n\x0fsourcesMetadata\x18\x03 \x03(\x0b\x32\x63.WABotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourceMetadata\x1a\xc6\x01\n\x1f\x42otPlanningSearchSourceMetadata\x12\r\n\x05title\x18\x01 \x01(\t\x12m\n\x08provider\x18\x02 \x01(\x0e\x32[.WABotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotSearchSourceProvider\x12\x11\n\tsourceURL\x18\x03 \x01(\t\x12\x12\n\nfavIconURL\x18\x04 \x01(\t\"P\n\x17\x42otSearchSourceProvider\x12\x14\n\x10UNKNOWN_PROVIDER\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x08\n\x04\x42ING\x10\x03\"K\n\x12PlanningStepStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PLANNED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x46INISHED\x10\x03\"\xb2\x0b\n\x15\x42otCapabilityMetadata\x12L\n\x0c\x63\x61pabilities\x18\x01 \x03(\x0e\x32\x36.WABotMetadata.BotCapabilityMetadata.BotCapabilityType\"\xca\n\n\x11\x42otCapabilityType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12PROGRESS_INDICATOR\x10\x01\x12\x19\n\x15RICH_RESPONSE_HEADING\x10\x02\x12\x1d\n\x19RICH_RESPONSE_NESTED_LIST\x10\x03\x12\r\n\tAI_MEMORY\x10\x04\x12 \n\x1cRICH_RESPONSE_THREAD_SURFING\x10\x05\x12\x17\n\x13RICH_RESPONSE_TABLE\x10\x06\x12\x16\n\x12RICH_RESPONSE_CODE\x10\x07\x12%\n!RICH_RESPONSE_STRUCTURED_RESPONSE\x10\x08\x12\x1e\n\x1aRICH_RESPONSE_INLINE_IMAGE\x10\t\x12#\n\x1fWA_IG_1P_PLUGIN_RANKING_CONTROL\x10\n\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_1\x10\x0b\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_2\x10\x0c\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_3\x10\r\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_4\x10\x0e\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_5\x10\x0f\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_6\x10\x10\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_7\x10\x11\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_8\x10\x12\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_9\x10\x13\x12%\n!WA_IG_1P_PLUGIN_RANKING_UPDATE_10\x10\x14\x12\x1d\n\x19RICH_RESPONSE_SUB_HEADING\x10\x15\x12\x1c\n\x18RICH_RESPONSE_GRID_IMAGE\x10\x16\x12\x18\n\x14\x41I_STUDIO_UGC_MEMORY\x10\x17\x12\x17\n\x13RICH_RESPONSE_LATEX\x10\x18\x12\x16\n\x12RICH_RESPONSE_MAPS\x10\x19\x12\x1e\n\x1aRICH_RESPONSE_INLINE_REELS\x10\x1a\x12\x14\n\x10\x41GENTIC_PLANNING\x10\x1b\x12\x13\n\x0f\x41\x43\x43OUNT_LINKING\x10\x1c\x12\x1c\n\x18STREAMING_DISAGGREGATION\x10\x1d\x12\x1f\n\x1bRICH_RESPONSE_GRID_IMAGE_3P\x10\x1e\x12\x1e\n\x1aRICH_RESPONSE_LATEX_INLINE\x10\x1f\x12\x0e\n\nQUERY_PLAN\x10 \x12\x15\n\x11PROACTIVE_MESSAGE\x10!\x12\"\n\x1eRICH_RESPONSE_UNIFIED_RESPONSE\x10\"\x12\x15\n\x11PROMOTION_MESSAGE\x10#\x12\x1b\n\x17SIMPLIFIED_PROFILE_PAGE\x10$\x12$\n RICH_RESPONSE_SOURCES_IN_MESSAGE\x10%\x12%\n!RICH_RESPONSE_SIDE_BY_SIDE_SURVEY\x10&\x12(\n$RICH_RESPONSE_UNIFIED_TEXT_COMPONENT\x10\'\x12\x14\n\x10\x41I_SHARED_MEMORY\x10(\x12!\n\x1dRICH_RESPONSE_UNIFIED_SOURCES\x10)\x12*\n&RICH_RESPONSE_UNIFIED_DOMAIN_CITATIONS\x10*\"\xa4\x01\n\x18\x42otModeSelectionMetadata\x12J\n\x04mode\x18\x01 \x03(\x0e\x32<.WABotMetadata.BotModeSelectionMetadata.BotUserSelectionMode\"<\n\x14\x42otUserSelectionMode\x12\x10\n\x0cUNKNOWN_MODE\x10\x00\x12\x12\n\x0eREASONING_MODE\x10\x01\"\xd8\x02\n\x10\x42otQuotaMetadata\x12X\n\x17\x62otFeatureQuotaMetadata\x18\x01 \x03(\x0b\x32\x37.WABotMetadata.BotQuotaMetadata.BotFeatureQuotaMetadata\x1a\xe9\x01\n\x17\x42otFeatureQuotaMetadata\x12[\n\x0b\x66\x65\x61tureType\x18\x01 \x01(\x0e\x32\x46.WABotMetadata.BotQuotaMetadata.BotFeatureQuotaMetadata.BotFeatureType\x12\x16\n\x0eremainingQuota\x18\x02 \x01(\r\x12\x1b\n\x13\x65xpirationTimestamp\x18\x03 \x01(\x04\"<\n\x0e\x42otFeatureType\x12\x13\n\x0fUNKNOWN_FEATURE\x10\x00\x12\x15\n\x11REASONING_FEATURE\x10\x01\"\xa0\x01\n\x12\x42otImagineMetadata\x12\x42\n\x0bimagineType\x18\x01 \x01(\x0e\x32-.WABotMetadata.BotImagineMetadata.ImagineType\"F\n\x0bImagineType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07IMAGINE\x10\x01\x12\x08\n\x04MEMU\x10\x02\x12\t\n\x05\x46LASH\x10\x03\x12\x08\n\x04\x45\x44IT\x10\x04\"\x94\x03\n\x12\x42otSourcesMetadata\x12@\n\x07sources\x18\x01 \x03(\x0b\x32/.WABotMetadata.BotSourcesMetadata.BotSourceItem\x1a\xbb\x02\n\rBotSourceItem\x12P\n\x08provider\x18\x01 \x01(\x0e\x32>.WABotMetadata.BotSourcesMetadata.BotSourceItem.SourceProvider\x12\x17\n\x0fthumbnailCDNURL\x18\x02 \x01(\t\x12\x19\n\x11sourceProviderURL\x18\x03 \x01(\t\x12\x13\n\x0bsourceQuery\x18\x04 \x01(\t\x12\x15\n\rfaviconCDNURL\x18\x05 \x01(\t\x12\x16\n\x0e\x63itationNumber\x18\x06 \x01(\r\x12\x13\n\x0bsourceTitle\x18\x07 \x01(\t\"K\n\x0eSourceProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x42ING\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x0b\n\x07SUPPORT\x10\x03\x12\t\n\x05OTHER\x10\x04\"\x98\x01\n\x10\x42otMessageOrigin\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32\x34.WABotMetadata.BotMessageOrigin.BotMessageOriginType\"@\n\x14\x42otMessageOriginType\x12(\n$BOT_MESSAGE_ORIGIN_TYPE_AI_INITIATED\x10\x00\"\xd6\x02\n\x0c\x41IThreadInfo\x12\x42\n\nserverInfo\x18\x01 \x01(\x0b\x32..WABotMetadata.AIThreadInfo.AIThreadServerInfo\x12\x42\n\nclientInfo\x18\x02 \x01(\x0b\x32..WABotMetadata.AIThreadInfo.AIThreadClientInfo\x1a\x98\x01\n\x12\x41IThreadClientInfo\x12I\n\x04type\x18\x01 \x01(\x0e\x32;.WABotMetadata.AIThreadInfo.AIThreadClientInfo.AIThreadType\"7\n\x0c\x41IThreadType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01\x12\r\n\tINCOGNITO\x10\x02\x1a#\n\x12\x41IThreadServerInfo\x12\r\n\x05title\x18\x01 \x01(\t\"s\n\x11\x42otAvatarMetadata\x12\x11\n\tsentiment\x18\x01 \x01(\r\x12\x15\n\rbehaviorGraph\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\r\x12\x11\n\tintensity\x18\x04 \x01(\r\x12\x11\n\twordCount\x18\x05 \x01(\r\"\xad\x01\n\x1a\x42otSuggestedPromptMetadata\x12\x18\n\x10suggestedPrompts\x18\x01 \x03(\t\x12\x1b\n\x13selectedPromptIndex\x18\x02 \x01(\r\x12>\n\x11promptSuggestions\x18\x03 \x01(\x0b\x32#.WABotMetadata.BotPromptSuggestions\x12\x18\n\x10selectedPromptID\x18\x04 \x01(\t\"O\n\x14\x42otPromptSuggestions\x12\x37\n\x0bsuggestions\x18\x01 \x03(\x0b\x32\".WABotMetadata.BotPromptSuggestion\"7\n\x13\x42otPromptSuggestion\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x10\n\x08promptID\x18\x02 \x01(\t\"y\n\x19\x42otLinkedAccountsMetadata\x12\x31\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x1f.WABotMetadata.BotLinkedAccount\x12\x14\n\x0c\x61\x63\x41uthTokens\x18\x02 \x01(\x0c\x12\x13\n\x0b\x61\x63\x45rrorCode\x18\x03 \x01(\x05\"\x8d\x01\n\x11\x42otMemoryMetadata\x12\x30\n\naddedFacts\x18\x01 \x03(\x0b\x32\x1c.WABotMetadata.BotMemoryFact\x12\x32\n\x0cremovedFacts\x18\x02 \x03(\x0b\x32\x1c.WABotMetadata.BotMemoryFact\x12\x12\n\ndisclaimer\x18\x03 \x01(\t\"-\n\rBotMemoryFact\x12\x0c\n\x04\x66\x61\x63t\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61\x63tID\x18\x02 \x01(\t\"g\n BotSignatureVerificationMetadata\x12\x43\n\x06proofs\x18\x01 \x03(\x0b\x32\x33.WABotMetadata.BotSignatureVerificationUseCaseProof\"\x8a\x01\n\x14\x42otRenderingMetadata\x12=\n\x08keywords\x18\x01 \x03(\x0b\x32+.WABotMetadata.BotRenderingMetadata.Keyword\x1a\x33\n\x07Keyword\x12\r\n\x05value\x18\x01 \x01(\t\x12\x19\n\x11\x61ssociatedPrompts\x18\x02 \x03(\t\"\xb0\x01\n\x12\x42otMetricsMetadata\x12\x15\n\rdestinationID\x18\x01 \x01(\t\x12\x42\n\x15\x64\x65stinationEntryPoint\x18\x02 \x01(\x0e\x32#.WABotMetadata.BotMetricsEntryPoint\x12?\n\x0cthreadOrigin\x18\x03 \x01(\x0e\x32).WABotMetadata.BotMetricsThreadEntryPoint\"_\n\x12\x42otSessionMetadata\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x36\n\rsessionSource\x18\x02 \x01(\x0e\x32\x1f.WABotMetadata.BotSessionSource\"F\n\x0f\x42otMemuMetadata\x12\x33\n\nfaceImages\x18\x01 \x03(\x0b\x32\x1f.WABotMetadata.BotMediaMetadata\"e\n\x18\x42otAgeCollectionMetadata\x12\x1d\n\x15\x61geCollectionEligible\x18\x01 \x01(\x08\x12*\n\"shouldTriggerAgeCollectionOnClient\x18\x02 \x01(\x08\"\x8a\x07\n\x16InThreadSurveyMetadata\x12\x16\n\x0etessaSessionID\x18\x01 \x01(\t\x12\x16\n\x0esimonSessionID\x18\x02 \x01(\t\x12\x15\n\rsimonSurveyID\x18\x03 \x01(\t\x12\x13\n\x0btessaRootID\x18\x04 \x01(\t\x12\x11\n\trequestID\x18\x05 \x01(\t\x12\x12\n\ntessaEvent\x18\x06 \x01(\t\x12\x1c\n\x14invitationHeaderText\x18\x07 \x01(\t\x12\x1a\n\x12invitationBodyText\x18\x08 \x01(\t\x12\x19\n\x11invitationCtaText\x18\t \x01(\t\x12\x18\n\x10invitationCtaURL\x18\n \x01(\t\x12\x13\n\x0bsurveyTitle\x18\x0b \x01(\t\x12O\n\tquestions\x18\x0c \x03(\x0b\x32<.WABotMetadata.InThreadSurveyMetadata.InThreadSurveyQuestion\x12 \n\x18surveyContinueButtonText\x18\r \x01(\t\x12\x1e\n\x16surveySubmitButtonText\x18\x0e \x01(\t\x12\x1c\n\x14privacyStatementFull\x18\x0f \x01(\t\x12g\n\x15privacyStatementParts\x18\x10 \x03(\x0b\x32H.WABotMetadata.InThreadSurveyMetadata.InThreadSurveyPrivacyStatementPart\x12\x19\n\x11\x66\x65\x65\x64\x62\x61\x63kToastText\x18\x11 \x01(\t\x1a?\n\"InThreadSurveyPrivacyStatementPart\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03URL\x18\x02 \x01(\t\x1aY\n\x14InThreadSurveyOption\x12\x13\n\x0bstringValue\x18\x01 \x01(\t\x12\x14\n\x0cnumericValue\x18\x02 \x01(\r\x12\x16\n\x0etextTranslated\x18\x03 \x01(\t\x1a\x97\x01\n\x16InThreadSurveyQuestion\x12\x14\n\x0cquestionText\x18\x01 \x01(\t\x12\x12\n\nquestionID\x18\x02 \x01(\t\x12S\n\x0fquestionOptions\x18\x03 \x03(\x0b\x32:.WABotMetadata.InThreadSurveyMetadata.InThreadSurveyOption\"L\n\x18\x42otMessageOriginMetadata\x12\x30\n\x07origins\x18\x01 \x03(\x0b\x32\x1f.WABotMetadata.BotMessageOrigin\"\x95\x03\n\x1a\x42otUnifiedResponseMutation\x12Q\n\x0bsbsMetadata\x18\x01 \x01(\x0b\x32<.WABotMetadata.BotUnifiedResponseMutation.SideBySideMetadata\x12`\n\x18mediaDetailsMetadataList\x18\x02 \x03(\x0b\x32>.WABotMetadata.BotUnifiedResponseMutation.MediaDetailsMetadata\x1a\x90\x01\n\x14MediaDetailsMetadata\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x35\n\x0chighResMedia\x18\x02 \x01(\x0b\x32\x1f.WABotMetadata.BotMediaMetadata\x12\x35\n\x0cpreviewMedia\x18\x03 \x01(\x0b\x32\x1f.WABotMetadata.BotMediaMetadata\x1a/\n\x12SideBySideMetadata\x12\x19\n\x11primaryResponseID\x18\x01 \x01(\t\"\xa2\x0e\n\x0b\x42otMetadata\x12\x38\n\x0e\x61vatarMetadata\x18\x01 \x01(\x0b\x32 .WABotMetadata.BotAvatarMetadata\x12\x11\n\tpersonaID\x18\x02 \x01(\t\x12\x38\n\x0epluginMetadata\x18\x03 \x01(\x0b\x32 .WABotMetadata.BotPluginMetadata\x12J\n\x17suggestedPromptMetadata\x18\x04 \x01(\x0b\x32).WABotMetadata.BotSuggestedPromptMetadata\x12\x12\n\ninvokerJID\x18\x05 \x01(\t\x12:\n\x0fsessionMetadata\x18\x06 \x01(\x0b\x32!.WABotMetadata.BotSessionMetadata\x12\x34\n\x0cmemuMetadata\x18\x07 \x01(\x0b\x32\x1e.WABotMetadata.BotMemuMetadata\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12<\n\x10reminderMetadata\x18\t \x01(\x0b\x32\".WABotMetadata.BotReminderMetadata\x12\x36\n\rmodelMetadata\x18\n \x01(\x0b\x32\x1f.WABotMetadata.BotModelMetadata\x12\x1d\n\x15messageDisclaimerText\x18\x0b \x01(\t\x12N\n\x19progressIndicatorMetadata\x18\x0c \x01(\x0b\x32+.WABotMetadata.BotProgressIndicatorMetadata\x12@\n\x12\x63\x61pabilityMetadata\x18\r \x01(\x0b\x32$.WABotMetadata.BotCapabilityMetadata\x12:\n\x0fimagineMetadata\x18\x0e \x01(\x0b\x32!.WABotMetadata.BotImagineMetadata\x12\x38\n\x0ememoryMetadata\x18\x0f \x01(\x0b\x32 .WABotMetadata.BotMemoryMetadata\x12>\n\x11renderingMetadata\x18\x10 \x01(\x0b\x32#.WABotMetadata.BotRenderingMetadata\x12=\n\x12\x62otMetricsMetadata\x18\x11 \x01(\x0b\x32!.WABotMetadata.BotMetricsMetadata\x12K\n\x19\x62otLinkedAccountsMetadata\x18\x12 \x01(\x0b\x32(.WABotMetadata.BotLinkedAccountsMetadata\x12\x46\n\x1brichResponseSourcesMetadata\x18\x13 \x01(\x0b\x32!.WABotMetadata.BotSourcesMetadata\x12\x1d\n\x15\x61iConversationContext\x18\x14 \x01(\x0c\x12O\n\x1b\x62otPromotionMessageMetadata\x18\x15 \x01(\x0b\x32*.WABotMetadata.BotPromotionMessageMetadata\x12I\n\x18\x62otModeSelectionMetadata\x18\x16 \x01(\x0b\x32\'.WABotMetadata.BotModeSelectionMetadata\x12\x39\n\x10\x62otQuotaMetadata\x18\x17 \x01(\x0b\x32\x1f.WABotMetadata.BotQuotaMetadata\x12I\n\x18\x62otAgeCollectionMetadata\x18\x18 \x01(\x0b\x32\'.WABotMetadata.BotAgeCollectionMetadata\x12#\n\x1b\x63onversationStarterPromptID\x18\x19 \x01(\t\x12\x15\n\rbotResponseID\x18\x1a \x01(\t\x12M\n\x14verificationMetadata\x18\x1b \x01(\x0b\x32/.WABotMetadata.BotSignatureVerificationMetadata\x12J\n\x17unifiedResponseMutation\x18\x1c \x01(\x0b\x32).WABotMetadata.BotUnifiedResponseMutation\x12I\n\x18\x62otMessageOriginMetadata\x18\x1d \x01(\x0b\x32\'.WABotMetadata.BotMessageOriginMetadata\x12\x45\n\x16inThreadSurveyMetadata\x18\x1e \x01(\x0b\x32%.WABotMetadata.InThreadSurveyMetadata\x12\x32\n\rbotThreadInfo\x18\x1f \x01(\x0b\x32\x1b.WABotMetadata.AIThreadInfo\x12\x19\n\x10internalMetadata\x18\xe7\x07 \x01(\x0c*\xc5\x06\n\x14\x42otMetricsEntryPoint\x12\x0b\n\x07\x46\x41VICON\x10\x01\x12\x0c\n\x08\x43HATLIST\x10\x02\x12#\n\x1f\x41ISEARCH_NULL_STATE_PAPER_PLANE\x10\x03\x12\"\n\x1e\x41ISEARCH_NULL_STATE_SUGGESTION\x10\x04\x12\"\n\x1e\x41ISEARCH_TYPE_AHEAD_SUGGESTION\x10\x05\x12#\n\x1f\x41ISEARCH_TYPE_AHEAD_PAPER_PLANE\x10\x06\x12\'\n#AISEARCH_TYPE_AHEAD_RESULT_CHATLIST\x10\x07\x12\'\n#AISEARCH_TYPE_AHEAD_RESULT_MESSAGES\x10\x08\x12\x16\n\x12\x41IVOICE_SEARCH_BAR\x10\t\x12\x13\n\x0f\x41IVOICE_FAVICON\x10\n\x12\x0c\n\x08\x41ISTUDIO\x10\x0b\x12\x0c\n\x08\x44\x45\x45PLINK\x10\x0c\x12\x10\n\x0cNOTIFICATION\x10\r\x12\x1a\n\x16PROFILE_MESSAGE_BUTTON\x10\x0e\x12\x0b\n\x07\x46ORWARD\x10\x0f\x12\x10\n\x0c\x41PP_SHORTCUT\x10\x10\x12\r\n\tFF_FAMILY\x10\x11\x12\n\n\x06\x41I_TAB\x10\x12\x12\x0b\n\x07\x41I_HOME\x10\x13\x12\x19\n\x15\x41I_DEEPLINK_IMMERSIVE\x10\x14\x12\x0f\n\x0b\x41I_DEEPLINK\x10\x15\x12#\n\x1fMETA_AI_CHAT_SHORTCUT_AI_STUDIO\x10\x16\x12\x1f\n\x1bUGC_CHAT_SHORTCUT_AI_STUDIO\x10\x17\x12\x16\n\x12NEW_CHAT_AI_STUDIO\x10\x18\x12 \n\x1c\x41IVOICE_FAVICON_CALL_HISTORY\x10\x19\x12\x1c\n\x18\x41SK_META_AI_CONTEXT_MENU\x10\x1a\x12!\n\x1d\x41SK_META_AI_CONTEXT_MENU_1ON1\x10\x1b\x12\"\n\x1e\x41SK_META_AI_CONTEXT_MENU_GROUP\x10\x1c\x12\x17\n\x13INVOKE_META_AI_1ON1\x10\x1d\x12\x18\n\x14INVOKE_META_AI_GROUP\x10\x1e\x12\x13\n\x0fMETA_AI_FORWARD\x10\x1f\x12\x17\n\x13NEW_CHAT_AI_CONTACT\x10 *\xa2\x01\n\x1a\x42otMetricsThreadEntryPoint\x12\x11\n\rAI_TAB_THREAD\x10\x01\x12\x12\n\x0e\x41I_HOME_THREAD\x10\x02\x12 \n\x1c\x41I_DEEPLINK_IMMERSIVE_THREAD\x10\x03\x12\x16\n\x12\x41I_DEEPLINK_THREAD\x10\x04\x12#\n\x1f\x41SK_META_AI_CONTEXT_MENU_THREAD\x10\x05*}\n\x10\x42otSessionSource\x12\x08\n\x04NONE\x10\x00\x12\x0e\n\nNULL_STATE\x10\x01\x12\r\n\tTYPEAHEAD\x10\x02\x12\x0e\n\nUSER_INPUT\x10\x03\x12\r\n\tEMU_FLASH\x10\x04\x12\x16\n\x12\x45MU_FLASH_FOLLOWUP\x10\x05\x12\t\n\x05VOICE\x10\x06\x42)Z\'go.mau.fi/whatsmeow/proto/waBotMetadata')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waBotMetadata.WABotMetadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'go.mau.fi/whatsmeow/proto/waBotMetadata'
  _globals['_BOTMETRICSENTRYPOINT']._serialized_start=11506
  _globals['_BOTMETRICSENTRYPOINT']._serialized_end=12343
  _globals['_BOTMETRICSTHREADENTRYPOINT']._serialized_start=12346
  _globals['_BOTMETRICSTHREADENTRYPOINT']._serialized_end=12508
  _globals['_BOTSESSIONSOURCE']._serialized_start=12510
  _globals['_BOTSESSIONSOURCE']._serialized_end=12635
  _globals['_BOTPLUGINMETADATA']._serialized_start=78
  _globals['_BOTPLUGINMETADATA']._serialized_end=723
  _globals['_BOTPLUGINMETADATA_PLUGINTYPE']._serialized_start=602
  _globals['_BOTPLUGINMETADATA_PLUGINTYPE']._serialized_end=657
  _globals['_BOTPLUGINMETADATA_SEARCHPROVIDER']._serialized_start=659
  _globals['_BOTPLUGINMETADATA_SEARCHPROVIDER']._serialized_end=723
  _globals['_BOTLINKEDACCOUNT']._serialized_start=726
  _globals['_BOTLINKEDACCOUNT']._serialized_end=868
  _globals['_BOTLINKEDACCOUNT_BOTLINKEDACCOUNTTYPE']._serialized_start=814
  _globals['_BOTLINKEDACCOUNT_BOTLINKEDACCOUNTTYPE']._serialized_end=868
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF']._serialized_start=871
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF']._serialized_end=1100
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF_BOTSIGNATUREUSECASE']._serialized_start=1063
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF_BOTSIGNATUREUSECASE']._serialized_end=1100
  _globals['_BOTPROMOTIONMESSAGEMETADATA']._serialized_start=1103
  _globals['_BOTPROMOTIONMESSAGEMETADATA']._serialized_end=1305
  _globals['_BOTPROMOTIONMESSAGEMETADATA_BOTPROMOTIONTYPE']._serialized_start=1239
  _globals['_BOTPROMOTIONMESSAGEMETADATA_BOTPROMOTIONTYPE']._serialized_end=1305
  _globals['_BOTMEDIAMETADATA']._serialized_start=1308
  _globals['_BOTMEDIAMETADATA']._serialized_end=1578
  _globals['_BOTMEDIAMETADATA_ORIENTATIONTYPE']._serialized_start=1528
  _globals['_BOTMEDIAMETADATA_ORIENTATIONTYPE']._serialized_end=1578
  _globals['_BOTREMINDERMETADATA']._serialized_start=1581
  _globals['_BOTREMINDERMETADATA']._serialized_end=1982
  _globals['_BOTREMINDERMETADATA_REMINDERFREQUENCY']._serialized_start=1837
  _globals['_BOTREMINDERMETADATA_REMINDERFREQUENCY']._serialized_end=1916
  _globals['_BOTREMINDERMETADATA_REMINDERACTION']._serialized_start=1918
  _globals['_BOTREMINDERMETADATA_REMINDERACTION']._serialized_end=1982
  _globals['_BOTMODELMETADATA']._serialized_start=1985
  _globals['_BOTMODELMETADATA']._serialized_end=2297
  _globals['_BOTMODELMETADATA_PREMIUMMODELSTATUS']._serialized_start=2147
  _globals['_BOTMODELMETADATA_PREMIUMMODELSTATUS']._serialized_end=2226
  _globals['_BOTMODELMETADATA_MODELTYPE']._serialized_start=2228
  _globals['_BOTMODELMETADATA_MODELTYPE']._serialized_end=2297
  _globals['_BOTPROGRESSINDICATORMETADATA']._serialized_start=2300
  _globals['_BOTPROGRESSINDICATORMETADATA']._serialized_end=3792
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA']._serialized_start=2454
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA']._serialized_end=3792
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA']._serialized_start=2919
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA']._serialized_end=3228
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA_BOTPLANNINGSEARCHSOURCEPROVIDER']._serialized_start=3149
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA_BOTPLANNINGSEARCHSOURCEPROVIDER']._serialized_end=3228
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSTEPSECTIONMETADATA']._serialized_start=3231
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSTEPSECTIONMETADATA']._serialized_end=3432
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCEMETADATA']._serialized_start=3435
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCEMETADATA']._serialized_end=3633
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTSEARCHSOURCEPROVIDER']._serialized_start=3635
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTSEARCHSOURCEPROVIDER']._serialized_end=3715
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_PLANNINGSTEPSTATUS']._serialized_start=3717
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_PLANNINGSTEPSTATUS']._serialized_end=3792
  _globals['_BOTCAPABILITYMETADATA']._serialized_start=3795
  _globals['_BOTCAPABILITYMETADATA']._serialized_end=5253
  _globals['_BOTCAPABILITYMETADATA_BOTCAPABILITYTYPE']._serialized_start=3899
  _globals['_BOTCAPABILITYMETADATA_BOTCAPABILITYTYPE']._serialized_end=5253
  _globals['_BOTMODESELECTIONMETADATA']._serialized_start=5256
  _globals['_BOTMODESELECTIONMETADATA']._serialized_end=5420
  _globals['_BOTMODESELECTIONMETADATA_BOTUSERSELECTIONMODE']._serialized_start=5360
  _globals['_BOTMODESELECTIONMETADATA_BOTUSERSELECTIONMODE']._serialized_end=5420
  _globals['_BOTQUOTAMETADATA']._serialized_start=5423
  _globals['_BOTQUOTAMETADATA']._serialized_end=5767
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA']._serialized_start=5534
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA']._serialized_end=5767
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA_BOTFEATURETYPE']._serialized_start=5707
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA_BOTFEATURETYPE']._serialized_end=5767
  _globals['_BOTIMAGINEMETADATA']._serialized_start=5770
  _globals['_BOTIMAGINEMETADATA']._serialized_end=5930
  _globals['_BOTIMAGINEMETADATA_IMAGINETYPE']._serialized_start=5860
  _globals['_BOTIMAGINEMETADATA_IMAGINETYPE']._serialized_end=5930
  _globals['_BOTSOURCESMETADATA']._serialized_start=5933
  _globals['_BOTSOURCESMETADATA']._serialized_end=6337
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM']._serialized_start=6022
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM']._serialized_end=6337
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM_SOURCEPROVIDER']._serialized_start=6262
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM_SOURCEPROVIDER']._serialized_end=6337
  _globals['_BOTMESSAGEORIGIN']._serialized_start=6340
  _globals['_BOTMESSAGEORIGIN']._serialized_end=6492
  _globals['_BOTMESSAGEORIGIN_BOTMESSAGEORIGINTYPE']._serialized_start=6428
  _globals['_BOTMESSAGEORIGIN_BOTMESSAGEORIGINTYPE']._serialized_end=6492
  _globals['_AITHREADINFO']._serialized_start=6495
  _globals['_AITHREADINFO']._serialized_end=6837
  _globals['_AITHREADINFO_AITHREADCLIENTINFO']._serialized_start=6648
  _globals['_AITHREADINFO_AITHREADCLIENTINFO']._serialized_end=6800
  _globals['_AITHREADINFO_AITHREADCLIENTINFO_AITHREADTYPE']._serialized_start=6745
  _globals['_AITHREADINFO_AITHREADCLIENTINFO_AITHREADTYPE']._serialized_end=6800
  _globals['_AITHREADINFO_AITHREADSERVERINFO']._serialized_start=6802
  _globals['_AITHREADINFO_AITHREADSERVERINFO']._serialized_end=6837
  _globals['_BOTAVATARMETADATA']._serialized_start=6839
  _globals['_BOTAVATARMETADATA']._serialized_end=6954
  _globals['_BOTSUGGESTEDPROMPTMETADATA']._serialized_start=6957
  _globals['_BOTSUGGESTEDPROMPTMETADATA']._serialized_end=7130
  _globals['_BOTPROMPTSUGGESTIONS']._serialized_start=7132
  _globals['_BOTPROMPTSUGGESTIONS']._serialized_end=7211
  _globals['_BOTPROMPTSUGGESTION']._serialized_start=7213
  _globals['_BOTPROMPTSUGGESTION']._serialized_end=7268
  _globals['_BOTLINKEDACCOUNTSMETADATA']._serialized_start=7270
  _globals['_BOTLINKEDACCOUNTSMETADATA']._serialized_end=7391
  _globals['_BOTMEMORYMETADATA']._serialized_start=7394
  _globals['_BOTMEMORYMETADATA']._serialized_end=7535
  _globals['_BOTMEMORYFACT']._serialized_start=7537
  _globals['_BOTMEMORYFACT']._serialized_end=7582
  _globals['_BOTSIGNATUREVERIFICATIONMETADATA']._serialized_start=7584
  _globals['_BOTSIGNATUREVERIFICATIONMETADATA']._serialized_end=7687
  _globals['_BOTRENDERINGMETADATA']._serialized_start=7690
  _globals['_BOTRENDERINGMETADATA']._serialized_end=7828
  _globals['_BOTRENDERINGMETADATA_KEYWORD']._serialized_start=7777
  _globals['_BOTRENDERINGMETADATA_KEYWORD']._serialized_end=7828
  _globals['_BOTMETRICSMETADATA']._serialized_start=7831
  _globals['_BOTMETRICSMETADATA']._serialized_end=8007
  _globals['_BOTSESSIONMETADATA']._serialized_start=8009
  _globals['_BOTSESSIONMETADATA']._serialized_end=8104
  _globals['_BOTMEMUMETADATA']._serialized_start=8106
  _globals['_BOTMEMUMETADATA']._serialized_end=8176
  _globals['_BOTAGECOLLECTIONMETADATA']._serialized_start=8178
  _globals['_BOTAGECOLLECTIONMETADATA']._serialized_end=8279
  _globals['_INTHREADSURVEYMETADATA']._serialized_start=8282
  _globals['_INTHREADSURVEYMETADATA']._serialized_end=9188
  _globals['_INTHREADSURVEYMETADATA_INTHREADSURVEYPRIVACYSTATEMENTPART']._serialized_start=8880
  _globals['_INTHREADSURVEYMETADATA_INTHREADSURVEYPRIVACYSTATEMENTPART']._serialized_end=8943
  _globals['_INTHREADSURVEYMETADATA_INTHREADSURVEYOPTION']._serialized_start=8945
  _globals['_INTHREADSURVEYMETADATA_INTHREADSURVEYOPTION']._serialized_end=9034
  _globals['_INTHREADSURVEYMETADATA_INTHREADSURVEYQUESTION']._serialized_start=9037
  _globals['_INTHREADSURVEYMETADATA_INTHREADSURVEYQUESTION']._serialized_end=9188
  _globals['_BOTMESSAGEORIGINMETADATA']._serialized_start=9190
  _globals['_BOTMESSAGEORIGINMETADATA']._serialized_end=9266
  _globals['_BOTUNIFIEDRESPONSEMUTATION']._serialized_start=9269
  _globals['_BOTUNIFIEDRESPONSEMUTATION']._serialized_end=9674
  _globals['_BOTUNIFIEDRESPONSEMUTATION_MEDIADETAILSMETADATA']._serialized_start=9481
  _globals['_BOTUNIFIEDRESPONSEMUTATION_MEDIADETAILSMETADATA']._serialized_end=9625
  _globals['_BOTUNIFIEDRESPONSEMUTATION_SIDEBYSIDEMETADATA']._serialized_start=9627
  _globals['_BOTUNIFIEDRESPONSEMUTATION_SIDEBYSIDEMETADATA']._serialized_end=9674
  _globals['_BOTMETADATA']._serialized_start=9677
  _globals['_BOTMETADATA']._serialized_end=11503
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloCoreTypeLink/InstamadilloCoreTypeLink.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloCoreTypeLink/InstamadilloCoreTypeLink.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloCoreTypeMedia import InstamadilloCoreTypeMedia_pb2 as instamadilloCoreTypeMedia_dot_InstamadilloCoreTypeMedia__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7instamadilloCoreTypeLink/InstamadilloCoreTypeLink.proto\x12\x18InstamadilloCoreTypeLink\x1a\x39instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\"P\n\x04Link\x12\x0c\n\x04text\x18\x01 \x01(\t\x12:\n\x0blinkContext\x18\x02 \x01(\x0b\x32%.InstamadilloCoreTypeLink.LinkContext\"\xab\x02\n\x0bLinkContext\x12\x38\n\x0clinkImageURL\x18\x01 \x01(\x0b\x32\".InstamadilloCoreTypeLink.ImageUrl\x12\x18\n\x10linkPreviewTitle\x18\x02 \x01(\t\x12\x0f\n\x07linkURL\x18\x03 \x01(\t\x12\x13\n\x0blinkSummary\x18\x04 \x01(\t\x12\x1b\n\x13linkMusicPreviewURL\x18\x05 \x01(\t\x12(\n linkMusicPreviewCountriesAllowed\x18\x06 \x03(\t\x12\x42\n\x14linkPreviewThumbnail\x18\x07 \x01(\x0b\x32$.InstamadilloCoreTypeMedia.Thumbnail\x12\x17\n\x0flinkPreviewBody\x18\x08 \x01(\t\"6\n\x08ImageUrl\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x42\x34Z2go.mau.fi/whatsmeow/proto/instamadilloCoreTypeLink')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloCoreTypeLink.InstamadilloCoreTypeLink_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2go.mau.fi/whatsmeow/proto/instamadilloCoreTypeLink'
  _globals['_LINK']._serialized_start=144
  _globals['_LINK']._serialized_end=224
  _globals['_LINKCONTEXT']._serialized_start=227
  _globals['_LINKCONTEXT']._serialized_end=526
  _globals['_IMAGEURL']._serialized_start=528
  _globals['_IMAGEURL']._serialized_end=582
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloCoreTypeCollection/InstamadilloCoreTypeCollection.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloCoreTypeCollection/InstamadilloCoreTypeCollection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloCoreTypeMedia import InstamadilloCoreTypeMedia_pb2 as instamadilloCoreTypeMedia_dot_InstamadilloCoreTypeMedia__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCinstamadilloCoreTypeCollection/InstamadilloCoreTypeCollection.proto\x12\x1eInstamadilloCoreTypeCollection\x1a\x39instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\"K\n\nCollection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x05media\x18\x02 \x03(\x0b\x32 .InstamadilloCoreTypeMedia.MediaB:Z8go.mau.fi/whatsmeow/proto/instamadilloCoreTypeCollection')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloCoreTypeCollection.InstamadilloCoreTypeCollection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8go.mau.fi/whatsmeow/proto/instamadilloCoreTypeCollection'
  _globals['_COLLECTION']._serialized_start=162
  _globals['_COLLECTION']._serialized_end=237
# @@protoc_insertion_point(module_scope)



from .client import NewClient
from .events import Event
from .utils.ffmpeg import FFmpeg
from .utils.iofile import TemporaryFile
__version__ = '0.3.11.post2'
__all__ = ('NewClient', 'FFmpeg', 'TemporaryFile', 'Event')


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloXmaContentRef/InstamadilloXmaContentRef.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloXmaContentRef/InstamadilloXmaContentRef.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9instamadilloXmaContentRef/InstamadilloXmaContentRef.proto\x12\x19InstamadilloXmaContentRef\"\x9c\x02\n\rXmaContentRef\x12<\n\nactionType\x18\x01 \x01(\x0e\x32(.InstamadilloXmaContentRef.XmaActionType\x12H\n\x0b\x63ontentType\x18\x02 \x01(\x0e\x32\x33.InstamadilloXmaContentRef.ReceiverFetchContentType\x12\x11\n\ttargetURL\x18\x03 \x01(\t\x12\x10\n\x08userName\x18\x04 \x01(\t\x12\x11\n\townerFbid\x18\x05 \x01(\t\x12K\n\x0b\x66\x65tchParams\x18\x06 \x01(\x0b\x32\x36.InstamadilloXmaContentRef.ReceiverFetchXmaFetchParams\"\xc1\x08\n\x1bReceiverFetchXmaFetchParams\x12U\n\x0fnoteFetchParams\x18\x01 \x01(\x0b\x32:.InstamadilloXmaContentRef.ReceiverFetchXmaNoteFetchParamsH\x00\x12W\n\x10storyFetchParams\x18\x02 \x01(\x0b\x32;.InstamadilloXmaContentRef.ReceiverFetchXmaStoryFetchParamsH\x00\x12[\n\x12profileFetchParams\x18\x03 \x01(\x0b\x32=.InstamadilloXmaContentRef.ReceiverFetchXmaProfileFetchParamsH\x00\x12U\n\x0f\x63lipFetchParams\x18\x04 \x01(\x0b\x32:.InstamadilloXmaContentRef.ReceiverFetchXmaClipFetchParamsH\x00\x12U\n\x0f\x66\x65\x65\x64\x46\x65tchParams\x18\x05 \x01(\x0b\x32:.InstamadilloXmaContentRef.ReceiverFetchXmaFeedFetchParamsH\x00\x12U\n\x0fliveFetchParams\x18\x06 \x01(\x0b\x32:.InstamadilloXmaContentRef.ReceiverFetchXmaLiveFetchParamsH\x00\x12[\n\x12\x63ommentFetchParams\x18\x07 \x01(\x0b\x32=.InstamadilloXmaContentRef.ReceiverFetchXmaCommentFetchParamsH\x00\x12g\n\x18locationShareFetchParams\x18\x08 \x01(\x0b\x32\x43.InstamadilloXmaContentRef.ReceiverFetchXmaLocationShareFetchParamsH\x00\x12\x61\n\x15reelsAudioFetchParams\x18\t \x01(\x0b\x32@.InstamadilloXmaContentRef.ReceiverFetchXmaReelsAudioFetchParamsH\x00\x12_\n\x14mediaNoteFetchParams\x18\n \x01(\x0b\x32?.InstamadilloXmaContentRef.ReceiverFetchXmaMediaNoteFetchParamsH\x00\x12g\n\x18socialContextFetchParams\x18\x0b \x01(\x0b\x32\x43.InstamadilloXmaContentRef.ReceiverFetchXmaSocialContextFetchParamsH\x00\x42\x1d\n\x1breceiverFetchXmaFetchParams\"3\n\x1fReceiverFetchXmaNoteFetchParams\x12\x10\n\x08noteIgid\x18\x01 \x01(\t\"E\n ReceiverFetchXmaStoryFetchParams\x12\x11\n\tstoryIgid\x18\x01 \x01(\t\x12\x0e\n\x06reelID\x18\x02 \x01(\t\"9\n\"ReceiverFetchXmaProfileFetchParams\x12\x13\n\x0bprofileIgid\x18\x01 \x01(\t\"4\n\x1fReceiverFetchXmaClipFetchParams\x12\x11\n\tmediaIgid\x18\x01 \x01(\t\"Y\n\x1fReceiverFetchXmaFeedFetchParams\x12\x11\n\tmediaIgid\x18\x01 \x01(\t\x12#\n\x1b\x63\x61rouselShareChildMediaIgid\x18\x02 \x01(\t\"3\n\x1fReceiverFetchXmaLiveFetchParams\x12\x10\n\x08liveIgid\x18\x01 \x01(\t\"9\n\"ReceiverFetchXmaCommentFetchParams\x12\x13\n\x0b\x63ommentFbid\x18\x01 \x01(\t\"@\n(ReceiverFetchXmaLocationShareFetchParams\x12\x14\n\x0clocationIgid\x18\x01 \x01(\t\":\n%ReceiverFetchXmaReelsAudioFetchParams\x12\x11\n\taudioIgid\x18\x01 \x01(\t\"\x8e\x01\n$ReceiverFetchXmaMediaNoteFetchParams\x12\x15\n\rmediaNoteIgid\x18\x01 \x01(\t\x12O\n\x0bmessageType\x18\x02 \x01(\x0e\x32:.InstamadilloXmaContentRef.MediaNoteFetchParamsMessageType\"=\n(ReceiverFetchXmaSocialContextFetchParams\x12\x11\n\tmediaIgid\x18\x01 \x01(\t*\x9e\x01\n\rXmaActionType\x12\x1f\n\x1bXMA_ACTION_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15XMA_ACTION_TYPE_SHARE\x10\x01\x12\x19\n\x15XMA_ACTION_TYPE_REPLY\x10\x02\x12\x19\n\x15XMA_ACTION_TYPE_REACT\x10\x03\x12\x1b\n\x17XMA_ACTION_TYPE_MENTION\x10\x04*\xc2\x04\n\x18ReceiverFetchContentType\x12+\n\'RECEIVER_FETCH_CONTENT_TYPE_UNSPECIFIED\x10\x00\x12$\n RECEIVER_FETCH_CONTENT_TYPE_NOTE\x10\x01\x12%\n!RECEIVER_FETCH_CONTENT_TYPE_STORY\x10\x02\x12\'\n#RECEIVER_FETCH_CONTENT_TYPE_PROFILE\x10\x03\x12$\n RECEIVER_FETCH_CONTENT_TYPE_CLIP\x10\x04\x12$\n RECEIVER_FETCH_CONTENT_TYPE_FEED\x10\x05\x12$\n RECEIVER_FETCH_CONTENT_TYPE_LIVE\x10\x06\x12\'\n#RECEIVER_FETCH_CONTENT_TYPE_COMMENT\x10\x07\x12.\n*RECEIVER_FETCH_CONTENT_TYPE_LOCATION_SHARE\x10\x08\x12+\n\'RECEIVER_FETCH_CONTENT_TYPE_REELS_AUDIO\x10\t\x12*\n&RECEIVER_FETCH_CONTENT_TYPE_MEDIA_NOTE\x10\n\x12/\n+RECEIVER_FETCH_CONTENT_TYPE_STORY_HIGHLIGHT\x10\x0b\x12.\n*RECEIVER_FETCH_CONTENT_TYPE_SOCIAL_CONTEXT\x10\x0c*\xb9\x01\n\x1fMediaNoteFetchParamsMessageType\x12\x34\n0MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12\x30\n,MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_MENTION\x10\x01\x12.\n*MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_REPLY\x10\x02\x42\x35Z3go.mau.fi/whatsmeow/proto/instamadilloXmaContentRef')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloXmaContentRef.InstamadilloXmaContentRef_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3go.mau.fi/whatsmeow/proto/instamadilloXmaContentRef'
  _globals['_XMAACTIONTYPE']._serialized_start=2242
  _globals['_XMAACTIONTYPE']._serialized_end=2400
  _globals['_RECEIVERFETCHCONTENTTYPE']._serialized_start=2403
  _globals['_RECEIVERFETCHCONTENTTYPE']._serialized_end=2981
  _globals['_MEDIANOTEFETCHPARAMSMESSAGETYPE']._serialized_start=2984
  _globals['_MEDIANOTEFETCHPARAMSMESSAGETYPE']._serialized_end=3169
  _globals['_XMACONTENTREF']._serialized_start=89
  _globals['_XMACONTENTREF']._serialized_end=373
  _globals['_RECEIVERFETCHXMAFETCHPARAMS']._serialized_start=376
  _globals['_RECEIVERFETCHXMAFETCHPARAMS']._serialized_end=1465
  _globals['_RECEIVERFETCHXMANOTEFETCHPARAMS']._serialized_start=1467
  _globals['_RECEIVERFETCHXMANOTEFETCHPARAMS']._serialized_end=1518
  _globals['_RECEIVERFETCHXMASTORYFETCHPARAMS']._serialized_start=1520
  _globals['_RECEIVERFETCHXMASTORYFETCHPARAMS']._serialized_end=1589
  _globals['_RECEIVERFETCHXMAPROFILEFETCHPARAMS']._serialized_start=1591
  _globals['_RECEIVERFETCHXMAPROFILEFETCHPARAMS']._serialized_end=1648
  _globals['_RECEIVERFETCHXMACLIPFETCHPARAMS']._serialized_start=1650
  _globals['_RECEIVERFETCHXMACLIPFETCHPARAMS']._serialized_end=1702
  _globals['_RECEIVERFETCHXMAFEEDFETCHPARAMS']._serialized_start=1704
  _globals['_RECEIVERFETCHXMAFEEDFETCHPARAMS']._serialized_end=1793
  _globals['_RECEIVERFETCHXMALIVEFETCHPARAMS']._serialized_start=1795
  _globals['_RECEIVERFETCHXMALIVEFETCHPARAMS']._serialized_end=1846
  _globals['_RECEIVERFETCHXMACOMMENTFETCHPARAMS']._serialized_start=1848
  _globals['_RECEIVERFETCHXMACOMMENTFETCHPARAMS']._serialized_end=1905
  _globals['_RECEIVERFETCHXMALOCATIONSHAREFETCHPARAMS']._serialized_start=1907
  _globals['_RECEIVERFETCHXMALOCATIONSHAREFETCHPARAMS']._serialized_end=1971
  _globals['_RECEIVERFETCHXMAREELSAUDIOFETCHPARAMS']._serialized_start=1973
  _globals['_RECEIVERFETCHXMAREELSAUDIOFETCHPARAMS']._serialized_end=2031
  _globals['_RECEIVERFETCHXMAMEDIANOTEFETCHPARAMS']._serialized_start=2034
  _globals['_RECEIVERFETCHXMAMEDIANOTEFETCHPARAMS']._serialized_end=2176
  _globals['_RECEIVERFETCHXMASOCIALCONTEXTFETCHPARAMS']._serialized_start=2178
  _globals['_RECEIVERFETCHXMASOCIALCONTEXTFETCHPARAMS']._serialized_end=2239
# @@protoc_insertion_point(module_scope)
